@@ -71,20 +71,21 @@ def deploy_code():
         exclude_files += env.excluded_files
     if env.has_key('cfg_shared_files'):
         for cfg_shared_file in env.cfg_shared_files:
-          cfg_present = fabtools.files.is_file(path='%s/config/%s' % (env.remote_shared_path, os.path.basename(cfg_shared_file)),
-                                              use_sudo=True)
-          if cfg_present is None:
-            fabtools.files.upload_template('/tmp/%s-%s/%s' % (
-                                             env.application_name,
-                                             env.tag.lower(),
-                                             cfg_shared_file
-                                             ),
-                                            os.path.join(env.remote_shared_path,'config'),
-                                            use_sudo=True)
-
-          exclude_files += cfg_shared_file
-
+            cfg_present = fabtools.files.is_file(
+                path='%s/config/%s' % (
+                    env.remote_shared_path, os.path.basename(cfg_shared_file)),
+                use_sudo=True)
+            if cfg_present is None:
+                fabtools.files.upload_template('/tmp/%s-%s/%s' % (
+                                               env.application_name,
+                                               env.tag.lower(),
+                                               cfg_shared_file
+                                               ),
+                                               os.path.join(
+                                               env.remote_shared_path, 'config'),
+                                               use_sudo=True)
 
+            exclude_files += cfg_shared_file
 
     env.remote_current_release = "%(releases_path)s/%(time).0f" % {
         'releases_path': env.remote_releases_path, 'time': time()}
@@ -137,14 +138,6 @@ def rollback_code():
     Rolls back to the previously deployed version
     """
     if len(env.releases) >= 2:
-        env.current_release = env.releases[-1]
-        env.previous_revision = env.releases[-2]
-        env.current_release = "%(releases_path)s/%(current_revision)s" % \
-            {'releases_path': env.remote_releases_path,
-             'current_revision': env.current_revision}
-        env.remote_previous_release = "%(releases_path)s/%(previous_revision)s" % \
-            {'releases_path': env.remote_releases_path,
-             'previous_revision': env.previous_revision}
         fabric.api.sudo("rm %(current_path)s; ln -s %(previous_release)s %(current_path)s && rm -rf %(current_release)s" %
                         {'current_release': env.current_release, 'previous_release': env.previous_release, 'current_path': env.remote_current_path})
 
@@ -158,9 +151,8 @@ def symlink():
                      'current_release': env.remote_current_release})
     if env.has_key('cfg_shared_files'):
         for cfg_shared_file in env.cfg_shared_files:
-          fabric.api.sudo("ln -nfs %(shared_path)s/config/%(file_name)s %(current_release)s/%(file)s" %
-                {'shared_path': env.remote_shared_path,
-                 'current_release': env.remote_current_release,
-                 'file': cfg_shared_file,
-                 'file_name':  os.path.basename(cfg_shared_file)})
-
+            fabric.api.sudo("ln -nfs %(shared_path)s/config/%(file_name)s %(current_release)s/%(file)s" %
+                            {'shared_path': env.remote_shared_path,
+                             'current_release': env.remote_current_release,
+                             'file': cfg_shared_file,
+                             'file_name':  os.path.basename(cfg_shared_file)})
